@@ -277,7 +277,7 @@ class BaseGridder(BaseEstimator):
         Calls ``fit`` on the data, evaluates the residuals (data - predicted
         data), and returns the coordinates, residuals, and weights.
 
-        No very useful by itself but this interface makes gridders compatible
+        Not very useful by itself but this interface makes gridders compatible
         with other processing operations and is used by :class:`verde.Chain` to
         join them together (for example, so you can fit a spline on the
         residuals of a trend).
@@ -361,6 +361,7 @@ class BaseGridder(BaseEstimator):
             "squared error (RMSE) in Verde 2.0.0. "
             "This may change model selection results slightly.",
             FutureWarning,
+            stacklevel=2,
         )
         return score_estimator("r2", self, coordinates, data, weights=weights)
 
@@ -458,15 +459,6 @@ class BaseGridder(BaseEstimator):
                 "Both coordinates and region were provided. "
                 + "Please pass region only if spacing or shape is specified."
             )
-        # Raise deprecation warning for the region, shape and spacing arguments
-        if spacing is not None or shape is not None or region is not None:
-            warnings.warn(
-                "The 'spacing', 'shape' and 'region' arguments will be removed "
-                + "in Verde v2.0.0. "
-                + "Please use the 'verde.grid_coordinates' function to define "
-                + "grid coordinates and pass them as the 'coordinates' argument.",
-                FutureWarning,
-            )
         # Get grid coordinates from coordinates parameter
         if coordinates is not None:
             ndim = get_ndim_horizontal_coords(*coordinates[:2])
@@ -531,6 +523,12 @@ class BaseGridder(BaseEstimator):
         dimensions and the data field(s) in the output
         :class:`pandas.DataFrame`. Default names are provided.
 
+        .. warning::
+
+            The ``scatter`` method is deprecated and will be removed in Verde
+            2.0.0. Use :func:`verde.scatter_points` and the ``predict`` method
+            instead.
+
         Parameters
         ----------
         region : list = [W, E, S, N]
@@ -570,6 +568,13 @@ class BaseGridder(BaseEstimator):
             The interpolated values on a random set of points.
 
         """
+        warnings.warn(
+            "The 'scatter' method is deprecated and will be removed in Verde "
+            "2.0.0. Use 'verde.scatter_points' and the 'predict' method "
+            "instead.",
+            FutureWarning,
+            stacklevel=2,
+        )
         dims = self._get_dims(dims)
         region = get_instance_region(self, region)
         coordinates = scatter_points(region, size, random_state=random_state, **kwargs)
